Module: Golem
- Defined in:
- lib/golem.rb,
lib/golem/version.rb
Overview
Golem provides an easy way to host and manage access to git repositories on a server under a single user. More details can be found:
- for configuration at Config,
- for database handling at DB,
- for access control at Access,
- for commands at Command,
- for general help at README.
Defined Under Namespace
Modules: Access, Command, Config, DB, Parser, Version
Class Method Summary
collapse
Class Method Details
17
18
19
20
|
# File 'lib/golem.rb', line 17
def self.configure(opts_or_path = nil, &block)
Config.configure(opts_or_path, &block)
self
end
|